@@ -3,13 +3,17 @@
 package acmedns
 
 import (
+	"context"
 	"errors"
 	"fmt"
+	"strings"
 
-	"github.com/cpu/goacmedns"
 	"github.com/go-acme/lego/v4/challenge"
 	"github.com/go-acme/lego/v4/challenge/dns01"
 	"github.com/go-acme/lego/v4/platform/config/env"
+	"github.com/go-acme/lego/v4/providers/dns/acmedns/internal"
+	"github.com/nrdcg/goacmedns"
+	"github.com/nrdcg/goacmedns/storage"
 )
 
 const (
@@ -19,54 +23,109 @@ const (
 	// EnvAPIBase is the environment variable name for the ACME-DNS API address.
 	// (e.g. https://acmedns.your-domain.com).
 	EnvAPIBase = envNamespace + "API_BASE"
+
+	// EnvAllowList are source networks using CIDR notation,
+	// e.g. "192.168.100.1/24,1.2.3.4/32,2002:c0a8:2a00::0/40".
+	EnvAllowList = envNamespace + "ALLOWLIST"
+
 	// EnvStoragePath is the environment variable name for the ACME-DNS JSON account data file.
 	// A per-domain account will be registered/persisted to this file and used for TXT updates.
 	EnvStoragePath = envNamespace + "STORAGE_PATH"
+
+	// EnvStorageBaseURL  is the environment variable name for the ACME-DNS JSON account data.
+	// The URL to the storage server.
+	EnvStorageBaseURL = envNamespace + "STORAGE_BASE_URL"
 )
 
 var _ challenge.Provider = (*DNSProvider)(nil)
 
+// Config is used to configure the creation of the DNSProvider.
+type Config struct {
+	APIBase        string
+	AllowList      []string
+	StoragePath    string
+	StorageBaseURL string
+}
+
+// NewDefaultConfig returns a default configuration for the DNSProvider.
+func NewDefaultConfig() *Config {
+	return &Config{}
+}
+
 // acmeDNSClient is an interface describing the goacmedns.Client functions the DNSProvider uses.
 // It makes it easier for tests to shim a mock Client into the DNSProvider.
 type acmeDNSClient interface {
 	// UpdateTXTRecord updates the provided account's TXT record
 	// to the given value or returns an error.
-	UpdateTXTRecord(account goacmedns.Account, value string) error
+	UpdateTXTRecord(ctx context.Context, account goacmedns.Account, value string) error
 	// RegisterAccount registers and returns a new account
 	// with the given allowFrom restriction or returns an error.
-	RegisterAccount(allowFrom []string) (goacmedns.Account, error)
+	RegisterAccount(ctx context.Context, allowFrom []string) (goacmedns.Account, error)
 }
 
 // DNSProvider implements the challenge.Provider interface.
 type DNSProvider struct {
+	config  *Config
 	client  acmeDNSClient
 	storage goacmedns.Storage
 }
 
-// NewDNSProvider creates an ACME-DNS provider using file based account storage.
-// Its configuration is loaded from the environment by reading EnvAPIBase and EnvStoragePath.
+// NewDNSProvider returns a DNSProvider instance configured for Joohoi's acme-dns.
 func NewDNSProvider() (*DNSProvider, error) {
-	values, err := env.Get(EnvAPIBase, EnvStoragePath)
+	values, err := env.Get(EnvAPIBase)
 	if err != nil {
 		return nil, fmt.Errorf("acme-dns: %w", err)
 	}
 
-	client := goacmedns.NewClient(values[EnvAPIBase])
-	storage := goacmedns.NewFileStorage(values[EnvStoragePath], 0o600)
-	return NewDNSProviderClient(client, storage)
-}
+	config := NewDefaultConfig()
+	config.APIBase = values[EnvAPIBase]
+	config.StoragePath = env.GetOrFile(EnvStoragePath)
+	config.StorageBaseURL = env.GetOrFile(EnvStorageBaseURL)
 
-// NewDNSProviderClient creates an ACME-DNS DNSProvider with the given acmeDNSClient and goacmedns.Storage.
-func NewDNSProviderClient(client acmeDNSClient, storage goacmedns.Storage) (*DNSProvider, error) {
-	if client == nil {
-		return nil, errors.New("ACME-DNS Client must be not nil")
+	allowList := env.GetOrFile(EnvAllowList)
+	if allowList != "" {
+		config.AllowList = strings.Split(allowList, ",")
 	}
 
-	if storage == nil {
-		return nil, errors.New("ACME-DNS Storage must be not nil")
+	return NewDNSProviderConfig(config)
+}
+
+// NewDNSProviderConfig return a DNSProvider instance configured for Joohoi's acme-dns.
+func NewDNSProviderConfig(config *Config) (*DNSProvider, error) {
+	if config == nil {
+		return nil, errors.New("acme-dns: the configuration of the DNS provider is nil")
+	}
+
+	st, err := getStorage(config)
+	if err != nil {
+		return nil, fmt.Errorf("acme-dns: %w", err)
+	}
+
+	client, err := goacmedns.NewClient(config.APIBase)
+	if err != nil {
+		return nil, fmt.Errorf("acme-dns: new client: %w", err)
 	}
 
 	return &DNSProvider{
+		config:  config,
+		client:  client,
+		storage: st,
+	}, nil
+}
+
+// NewDNSProviderClient creates an ACME-DNS DNSProvider with the given acmeDNSClient and [goacmedns.Storage].
+// Deprecated: use [NewDNSProviderConfig] instead.
+func NewDNSProviderClient(client acmeDNSClient, storage goacmedns.Storage) (*DNSProvider, error) {
+	if client == nil {
+		return nil, errors.New("acme-dns: Client must be not nil")
+	}
+
+	if storage == nil {
+		return nil, errors.New("acme-dns: Storage must be not nil")
+	}
+
+	return &DNSProvider{
+		config:  NewDefaultConfig(),
 		client:  client,
 		storage: storage,
 	}, nil
@@ -105,24 +164,28 @@ func (e ErrCNAMERequired) Error() string {
 // one will be created and registered with the ACME DNS server and an ErrCNAMERequired error is returned.
 // This will halt issuance and indicate to the user that a one-time manual setup is required for the domain.
 func (d *DNSProvider) Present(domain, _, keyAuth string) error {
+	ctx := context.Background()
+
 	// Compute the challenge response FQDN and TXT value for the domain based on the keyAuth.
 	info := dns01.GetChallengeInfo(domain, keyAuth)
 
 	// Check if credentials were previously saved for this domain.
-	account, err := d.storage.Fetch(domain)
+	account, err := d.storage.Fetch(ctx, domain)
 	if err != nil {
-		if errors.Is(err, goacmedns.ErrDomainNotFound) {
-			// The account did not exist.
-			// Create a new one and return an error indicating the required one-time manual CNAME setup.
-			return d.register(domain, info.FQDN)
+		if !errors.Is(err, storage.ErrDomainNotFound) {
+			return err
 		}
 
-		// Errors other than goacmedns.ErrDomainNotFound are unexpected.
-		return err
+		// The account did not exist.
+		// Create a new one and return an error indicating the required one-time manual CNAME setup.
+		account, err = d.register(ctx, domain, info.FQDN)
+		if err != nil {
+			return err
+		}
 	}
 
 	// Update the acme-dns TXT record.
-	return d.client.UpdateTXTRecord(account, info.Value)
+	return d.client.UpdateTXTRecord(ctx, account, info.Value)
 }
 
 // CleanUp removes the record matching the specified parameters. It is not
@@ -137,29 +200,59 @@ func (d *DNSProvider) CleanUp(_, _, _ string) error {
 // If account creation works as expected a ErrCNAMERequired error is returned describing
 // the one-time manual CNAME setup required to complete setup of the ACME-DNS hook for the domain.
 // If any other error occurs it is returned as-is.
-func (d *DNSProvider) register(domain, fqdn string) error {
-	// TODO(@cpu): Read CIDR whitelists from the environment
-	newAcct, err := d.client.RegisterAccount(nil)
+func (d *DNSProvider) register(ctx context.Context, domain, fqdn string) (goacmedns.Account, error) {
+	newAcct, err := d.client.RegisterAccount(ctx, d.config.AllowList)
 	if err != nil {
-		return err
+		return goacmedns.Account{}, err
 	}
 
+	var cnameCreated bool
+
 	// Store the new account in the storage and call save to persist the data.
-	err = d.storage.Put(domain, newAcct)
+	err = d.storage.Put(ctx, domain, newAcct)
 	if err != nil {
-		return err
+		cnameCreated = errors.Is(err, internal.ErrCNAMEAlreadyCreated)
+		if !cnameCreated {
+			return goacmedns.Account{}, err
+		}
 	}
-	err = d.storage.Save()
+
+	err = d.storage.Save(ctx)
 	if err != nil {
-		return err
+		return goacmedns.Account{}, err
+	}
+
+	if cnameCreated {
+		return newAcct, nil
 	}
 
 	// Stop issuance by returning an error.
 	// The user needs to perform a manual one-time CNAME setup in their DNS zone
 	// to complete the setup of the new account we created.
-	return ErrCNAMERequired{
+	return goacmedns.Account{}, ErrCNAMERequired{
 		Domain: domain,
 		FQDN:   fqdn,
 		Target: newAcct.FullDomain,
 	}
 }
+
+func getStorage(config *Config) (goacmedns.Storage, error) {
+	if config.StoragePath == "" && config.StorageBaseURL == "" {
+		return nil, errors.New("storagePath or storageBaseURL is not set")
+	}
+
+	if config.StoragePath != "" && config.StorageBaseURL != "" {
+		return nil, errors.New("storagePath and storageBaseURL cannot be used at the same time")
+	}
+
+	if config.StoragePath != "" {
+		return storage.NewFile(config.StoragePath, 0o600), nil
+	}
+
+	st, err := internal.NewHTTPStorage(config.StorageBaseURL)
+	if err != nil {
+		return nil, fmt.Errorf("new HTTP storage: %w", err)
+	}
+
+	return st, nil
+}
