@@ -382,62 +382,62 @@ func TestClient_AddTxtRecord(t *testing.T) {
 		{
 			desc:        "sub-zone",
 			authID:      "myAuthID",
-			zoneName:    "bar.com",
-			authFQDN:    "_acme-challenge.foo.bar.com.",
+			zoneName:    "example.com",
+			authFQDN:    "_acme-challenge.foo.example.com.",
 			value:       "txtTXTtxtTXTtxtTXTtxtTXT",
 			ttl:         60,
 			apiResponse: `{"status":"Success","statusDescription":"The record was added successfully."}`,
 			expected: expected{
-				query: `auth-id=myAuthID&auth-password=myAuthPassword&domain-name=bar.com&host=_acme-challenge.foo&record=txtTXTtxtTXTtxtTXTtxtTXT&record-type=TXT&ttl=60`,
+				query: `auth-id=myAuthID&auth-password=myAuthPassword&domain-name=example.com&host=_acme-challenge.foo&record=txtTXTtxtTXTtxtTXTtxtTXT&record-type=TXT&ttl=60`,
 			},
 		},
 		{
 			desc:        "main zone (authID)",
 			authID:      "myAuthID",
-			zoneName:    "bar.com",
-			authFQDN:    "_acme-challenge.bar.com.",
+			zoneName:    "example.com",
+			authFQDN:    "_acme-challenge.example.com.",
 			value:       "TXTtxtTXTtxtTXTtxtTXTtxt",
 			ttl:         60,
 			apiResponse: `{"status":"Success","statusDescription":"The record was added successfully."}`,
 			expected: expected{
-				query: `auth-id=myAuthID&auth-password=myAuthPassword&domain-name=bar.com&host=_acme-challenge&record=TXTtxtTXTtxtTXTtxtTXTtxt&record-type=TXT&ttl=60`,
+				query: `auth-id=myAuthID&auth-password=myAuthPassword&domain-name=example.com&host=_acme-challenge&record=TXTtxtTXTtxtTXTtxtTXTtxt&record-type=TXT&ttl=60`,
 			},
 		},
 		{
 			desc:        "main zone (subAuthID)",
 			subAuthID:   "mySubAuthID",
-			zoneName:    "bar.com",
-			authFQDN:    "_acme-challenge.bar.com.",
+			zoneName:    "example.com",
+			authFQDN:    "_acme-challenge.example.com.",
 			value:       "TXTtxtTXTtxtTXTtxtTXTtxt",
 			ttl:         60,
 			apiResponse: `{"status":"Success","statusDescription":"The record was added successfully."}`,
 			expected: expected{
-				query: `auth-password=myAuthPassword&domain-name=bar.com&host=_acme-challenge&record=TXTtxtTXTtxtTXTtxtTXTtxt&record-type=TXT&sub-auth-id=mySubAuthID&ttl=60`,
+				query: `auth-password=myAuthPassword&domain-name=example.com&host=_acme-challenge&record=TXTtxtTXTtxtTXTtxtTXTtxt&record-type=TXT&sub-auth-id=mySubAuthID&ttl=60`,
 			},
 		},
 		{
 			desc:        "invalid status",
 			authID:      "myAuthID",
-			zoneName:    "bar.com",
-			authFQDN:    "_acme-challenge.bar.com.",
+			zoneName:    "example.com",
+			authFQDN:    "_acme-challenge.example.com.",
 			value:       "TXTtxtTXTtxtTXTtxtTXTtxt",
 			ttl:         120,
 			apiResponse: `{"status":"Failed","statusDescription":"Invalid TTL. Choose from the list of the values we support."}`,
 			expected: expected{
-				query:    `auth-id=myAuthID&auth-password=myAuthPassword&domain-name=bar.com&host=_acme-challenge&record=TXTtxtTXTtxtTXTtxtTXTtxt&record-type=TXT&ttl=300`,
+				query:    `auth-id=myAuthID&auth-password=myAuthPassword&domain-name=example.com&host=_acme-challenge&record=TXTtxtTXTtxtTXTtxtTXTtxt&record-type=TXT&ttl=300`,
 				errorMsg: "failed to add TXT record: Failed Invalid TTL. Choose from the list of the values we support.",
 			},
 		},
 		{
 			desc:        "invalid json response",
 			authID:      "myAuthID",
-			zoneName:    "bar.com",
-			authFQDN:    "_acme-challenge.bar.com.",
+			zoneName:    "example.com",
+			authFQDN:    "_acme-challenge.example.com.",
 			value:       "TXTtxtTXTtxtTXTtxtTXTtxt",
 			ttl:         120,
 			apiResponse: `[{}]`,
 			expected: expected{
-				query:    `auth-id=myAuthID&auth-password=myAuthPassword&domain-name=bar.com&host=_acme-challenge&record=TXTtxtTXTtxtTXTtxtTXTtxt&record-type=TXT&ttl=300`,
+				query:    `auth-id=myAuthID&auth-password=myAuthPassword&domain-name=example.com&host=_acme-challenge&record=TXTtxtTXTtxtTXTtxtTXTtxt&record-type=TXT&ttl=300`,
 				errorMsg: "unable to unmarshal response: [status code: 200] body: [{}] error: json: cannot unmarshal array into Go value of type internal.apiResponse",
 			},
 		},
