@@ -21,6 +21,7 @@ import (
 	"github.com/go-acme/lego/v4/challenge/dns01"
 	"github.com/go-acme/lego/v4/platform/config/env"
 	"github.com/go-acme/lego/v4/platform/wait"
+	"github.com/go-acme/lego/v4/providers/dns/internal/ptr"
 )
 
 // Environment variables names.
@@ -151,7 +152,7 @@ func (d *DNSProvider) Present(domain, token, keyAuth string) error {
 
 	var found bool
 	for _, record := range records {
-		if deref(record.Value) == realValue {
+		if ptr.Deref(record.Value) == realValue {
 			found = true
 		}
 	}
@@ -196,7 +197,7 @@ func (d *DNSProvider) CleanUp(domain, token, keyAuth string) error {
 
 	var nonLegoRecords []awstypes.ResourceRecord
 	for _, record := range existingRecords {
-		if deref(record.Value) != `"`+info.Value+`"` {
+		if ptr.Deref(record.Value) != `"`+info.Value+`"` {
 			nonLegoRecords = append(nonLegoRecords, record)
 		}
 	}
@@ -255,7 +256,7 @@ func (d *DNSProvider) changeRecord(ctx context.Context, action awstypes.ChangeAc
 				return true, nil
 			}
 
-			return false, fmt.Errorf("unable to retrieve change: ID=%s", deref(changeID))
+			return false, fmt.Errorf("unable to retrieve change: ID=%s", ptr.Deref(changeID))
 		})
 	}
 
@@ -281,7 +282,7 @@ func (d *DNSProvider) getExistingRecordSets(ctx context.Context, hostedZoneID, f
 	var records []awstypes.ResourceRecord
 
 	for _, recordSet := range recordSetsOutput.ResourceRecordSets {
-		if deref(recordSet.Name) == fqdn {
+		if ptr.Deref(recordSet.Name) == fqdn {
 			records = append(records, recordSet.ResourceRecords...)
 		}
 	}
@@ -311,8 +312,8 @@ func (d *DNSProvider) getHostedZoneID(ctx context.Context, fqdn string) (string,
 	var hostedZoneID string
 	for _, hostedZone := range resp.HostedZones {
 		// .Name has a trailing dot
-		if !hostedZone.Config.PrivateZone && deref(hostedZone.Name) == authZone {
-			hostedZoneID = deref(hostedZone.Id)
+		if !hostedZone.Config.PrivateZone && ptr.Deref(hostedZone.Name) == authZone {
+			hostedZoneID = ptr.Deref(hostedZone.Id)
 			break
 		}
 	}
@@ -394,12 +395,3 @@ func createAWSConfigCheckParams(config *Config) error {
 
 	return nil
 }
-
-func deref[T string | int | int32 | int64 | bool](v *T) T {
-	if v == nil {
-		var zero T
-		return zero
-	}
-
-	return *v
-}
